%define        libname  lib%{name}
%define        gitver %(echo %version | tr . _)
Name:          fuse3
Version:       3.10.5
Release:       1mamba
Summary:       File System in Userspace (FUSE) utilities
Group:         System/Tools
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://github.com/libfuse/libfuse
Source:        https://github.com/libfuse/libfuse.git/fuse-%{version}/libfuse-%{version}.tar.bz2
License:       GPL, LGPL
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
## AUTOBUILDREQ-END
BuildRequires: libselinux-devel
Requires:      %{libname} = %{?epoch:%epoch:}%{version}-%{release}

%description
With FUSE it is possible to implement a fully functional filesystem in a userspace program.
Features include:

- simple library API
- simple installation (no need to patch or recompile the kernel)
- secure implementation
- userspace - kernel interface is very efficient
- usable by non privileged users
- runs on Linux kernels 2.4.X and 2.6.X
- has proven very stable over time.

%package -n %{libname}
Summary:       File System in Userspace (FUSE) libraries
Group:         System/Libraries

%description -n %{libname}
Libraries for FUSE.

%package -n %{libname}-devel
Summary:       Devel package for %{libname}
Group:         Development/Libraries
Requires:      %{libname} = %{?epoch:%epoch:}%{version}-%{release}

%description -n %{libname}-devel
Libraries for FUSE.
This package contains static libraries and header files needed for development.

%debug_package

%prep
%setup -q -n libfuse-%{version}
sed -i "s|^chown root|#chown root|" util/install_helper.sh
sed -i "s|mknod|#mknod|" util/install_helper.sh

%build
%meson \
   -Duseroot=false \
   -Dudevrulesdir=%{_udevrulesdir}

%meson_build

%install
[ "%{buildroot}" != / ] && rm -rf %{buildroot}
%meson_install

rm -rf %{buildroot}/etc/init.d
rm -f %{buildroot}%{_sysconfdir}/fuse.conf

%clean
[ "%{buildroot}" != / ] && rm -rf %{buildroot}

%post   -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
#%config(noreplace) %{_sysconfdir}/fuse.conf
%{_udevrulesdir}/99-fuse3.rules
%{_bindir}/fusermount3
%{_sbindir}/mount.fuse3
%{_mandir}/man1/fusermount3.1*
%{_mandir}/man8/mount.fuse3.8*

%files -n %{libname}
%defattr(-,root,root)
%{_libdir}/libfuse3.so.*
%doc AUTHORS LICENSE

%files -n %{libname}-devel
%defattr(-,root,root)
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/*.h
%{_libdir}/libfuse3.so
%{_libdir}/pkgconfig/fuse3.pc
#%doc ChangeLog NEWS README.NFS

%changelog
* Mon Sep 06 2021 Automatic Build System <autodist@mambasoft.it> 3.10.5-1mamba
- automatic version update by autodist

* Sat Jun 19 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 3.10.4-1mamba
- update to 3.10.4

* Mon Apr 12 2021 Automatic Build System <autodist@mambasoft.it> 3.10.3-1mamba
- automatic version update by autodist

* Fri Feb 19 2021 Automatic Build System <autodist@mambasoft.it> 3.10.2-1mamba
- automatic version update by autodist

* Fri Dec 11 2020 Automatic Build System <autodist@mambasoft.it> 3.10.1-1mamba
- automatic version update by autodist

* Mon Oct 12 2020 Automatic Build System <autodist@mambasoft.it> 3.10.0-1mamba
- automatic version update by autodist

* Tue Aug 18 2020 Automatic Build System <autodist@mambasoft.it> 3.9.3-1mamba
- automatic version update by autodist

* Sun Jun 21 2020 Automatic Build System <autodist@mambasoft.it> 3.9.2-1mamba
- automatic version update by autodist

* Fri Mar 20 2020 Automatic Build System <autodist@mambasoft.it> 3.9.1-1mamba
- automatic version update by autodist

* Wed Dec 18 2019 Automatic Build System <autodist@mambasoft.it> 3.9.0-1mamba
- automatic version update by autodist

* Thu Dec 12 2019 Automatic Build System <autodist@mambasoft.it> 3.8.0-1mamba
- automatic version update by autodist

* Fri Jan 26 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 3.2.1-1mamba
- update to 3.2.1

* Sun Jul 31 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 2.9.7-1mamba
- update to 2.9.7

* Sat Jan 23 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 2.9.5-1mamba
- update to 2.9.5

* Sat May 23 2015 Automatic Build System <autodist@mambasoft.it> 2.9.4-1mamba
- automatic version update by autodist

* Sat Jul 06 2013 Automatic Build System <autodist@mambasoft.it> 2.9.3-1mamba
- automatic version update by autodist

* Sun Dec 02 2012 Automatic Build System <autodist@mambasoft.it> 2.9.2-1mamba
- automatic version update by autodist

* Sat Feb 25 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 2.8.7-1mamba
- update to 2.8.7
- added patch to fix linking issues with gold linker

* Thu Sep 30 2010 Automatic Build System <autodist@mambasoft.it> 2.8.5-1mamba
- automatic update by autodist

* Tue May 11 2010 Automatic Build System <autodist@mambasoft.it> 2.8.4-1mamba
- automatic update by autodist

* Thu Dec 31 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.8.1-1mamba
- update to 2.8.1
- fusermount: set suid for users group

* Thu Aug 27 2009 Automatic Build System <autodist@mambasoft.it> 2.8.0-1mamba
- automatic update by autodist

* Sun Nov 02 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.7.4-1mamba
- automatic update by autodist

* Sat Nov 17 2007 Stefano Cotta Ramusino <stefano.cotta@openmamba.org> 2.7.1-1mamba
- update to 2.7.1

* Sat Aug 25 2007 Stefano Cotta Ramusino <stefano.cotta@openmamba.org> 2.7.0-1mamba
- update to 2.7.0

* Thu May 03 2007 Stefano Cotta Ramusino <stefano.cotta@openmamba.org> 2.6.5-1mamba
- update to 2.6.5

* Fri Apr 27 2007 Stefano Cotta Ramusino <stefano.cotta@openmamba.org> 2.6.3-2mamba
- allow users to umount fuse filesystems

* Wed Apr 18 2007 Stefano Cotta Ramusino <stefano.cotta@openmamba.org> 2.6.3-1mamba
- update to version 2.6.3 by autospec
- added init script

* Mon Oct 16 2006 Davide Madrisan <davide.madrisan@qilinux.it> 2.5.3-2qilnx
- patched configuration file for udev to make it compatibile with latest udev
  versions
- replace the udev configuration rule and do a backup copy of the previous one

* Tue Jun 27 2006 Stefano Cotta Ramusino <stefano.cotta@qilinux.it> 2.5.3-1qilnx
- update to version 2.5.3 by autospec

* Fri Apr 14 2006 Stefano Cotta Ramusino <stefano.cotta@qilinux.it> 2.5.2-2qilnx
- added autoboot for fuse module

* Mon Mar 13 2006 Stefano Cotta Ramusino <stefano.cotta@qilinux.it> 2.5.2-1qilnx
- package created by autospec
